@@ -3,30 +3,21 @@ import pigpio
 from iot_gh.GHgpio import GHgpio
 
 class GHServo(object):
-    """This class GHFan provides a services to control the IoT Greenhouse servo
+    """A class to access the IoT Greenhouse servo.
     """    
     FREQ = 50
     PERIOD = 1/FREQ
     CCW_PW_LIMIT = 2000
     CW_PW_LIMIT = 500
-    _pi = None
-    _gpio = 0
-
-    _ccw_pulse_width = CCW_PW_LIMIT
-    _cw_pulse_width = CW_PW_LIMIT
-   
-    _pulse_width = CCW_PW_LIMIT
-    
-    position = 0
     
     def __init__(self, pi, servo_gpio,  cw_position, ccw_position):
-        """Constructor for class GHServo
+        """Initializes the IoT Greenhouse servo.
         
         :param pi: reference to pigpio service
         :param servo_gpio: GPIO PWM port for servo. Must be hardware PWM pin
         :param ccw_position: Counter-clockwise pulse width in microseconds
         :param cw_position: Clockwise pulse width in microseconds
-        :returns: GHFan object
+        :returns: GHServo object
         """
         #cw and ccw position in microseconds
         if cw_position < self.CW_PW_LIMIT:
@@ -51,7 +42,7 @@ class GHServo(object):
         if position < 0 or position > +1:
             raise ValueError("Error: Servo position is specified between 0 (full CCW) and 1 (full CW).")
         
-        pw = self._cw_pulse_width + position * (self._ccw_pulse_width - self._cw_pulse_width)
+        pw = self._ccw_pulse_width - position * (self._ccw_pulse_width - self._cw_pulse_width)
         return pw
 
     def _calc_duty_cycle(self, pulse_width):
@@ -62,9 +53,9 @@ class GHServo(object):
         return dc
 
     def move(self, position=0):
-        """ Normalized move method with -0 being max left (ccw) and +1 being max right (cw)
+        """ Normalized move method with 0 being max left (ccw) and +1 being max right (cw)
         
-        :param position: Normalized position value between -1.0 and +1.0.
+        :param position: Normalized position value between 0 and +1.0.
         """
         if position < 0 or position > 1:
             raise Exception("Error: Position values must be between 0 and 1.0.")
@@ -74,15 +65,25 @@ class GHServo(object):
             self._pi.hardware_PWM(self._gpio, self.FREQ, dc)       
 
     def is_ccw(self):
+        """Returns Boolean indicating servo is fully counter-clockwise.
+        """
         return self._position == 0
 
     def is_cw(self):
+        """Returns Boolean indicating servo is fully clockwise.
+        """
         return self._position == +1
 
     def get_value(self):
+        """Returns current position of servo.
+        """
         return self._position
 
     def get_status(self):
+        """Gets status of servo.
+
+        :returns: Servo status as string.
+        """
         if self.is_ccw():
             return "CLOSED"
         elif self.is_cw():
