@@ -2,17 +2,11 @@ from time import sleep
 import pigpio
 
 class GHSwitches(object):
-    """This class GHSwtiches provides a services to control the both IoT Greenhouse switches
+    """A container class to access the IoT Greenhouse switches.
     """
-
-    SWITCH_ON = False
-    SWITCH_OFF = True
-    
-    push_button = None
-    toggle = None
-    
+   
     def __init__(self, pi, pb_switch_gpio, toggle_switch_gpio):
-        """Constructor for class GHSwitches
+        """Initializes a container for IoT Greenhouse switches.
     
         Returns references to both push button and toggle switches
 
@@ -25,14 +19,13 @@ class GHSwitches(object):
         self.toggle = GHSwitch(pi, toggle_switch_gpio)
 
 class GHSwitch(object):
-    """This class GHSwtiches provides a services to an IoT Greenhouse switch
-    """
-        
-    _pi = None
-    _gpio = 0
-    
+    """A class to access IoT Greenhouse switch.
+    """  
+    SWITCH_ON = False
+    SWITCH_OFF = True
+       
     def __init__(self, pi, switch_gpio):
-        """Constructor for class GHSwitch
+        """Initializes an IoT Greenhouse switch.
         
         Returns references to switch object. Used for both push button and toggle.
 
@@ -45,7 +38,8 @@ class GHSwitch(object):
         self._pi.set_mode(self._gpio, pigpio.INPUT)        
         
     def get_state(self, debounce=False):
-        #debounce
+        """Returns current state of switch. 
+        """
         if not debounce:
             return self._pi.read(self._gpio)
         else:
@@ -59,27 +53,39 @@ class GHSwitch(object):
             return first_read
 
     def wait_for_press(self):
-        #Wait for on - active low
+        """Waits for switch on or switch pressed state.
+        """
         while self.get_state():
-            sleep(.5)
+            sleep(.2)
 
     def wait_for_release(self):
-        #Wait for off - active low
+        """Waits for switch off or switch released state.
+        """
         while not self.get_state():
-            sleep(.5)
+            sleep(.2)
 
     def wait_for_press_and_release(self):
+        """Waits for switch press and released states.
+        """
         self.wait_for_press()
         self.wait_for_release()
 
     def is_on(self):
-        return self.get_state() == GHSwitches.SWITCH_ON
+        """Returns Boolean indicating switch is on.
+        """
+        return self.get_state() == GHSwitch.SWITCH_ON
 
     def is_off(self):
-        return self.get_state() == GHSwitches.SWITCH_OFF
+        """Returns Boolean indicating switch is off.
+        """
+        return self.get_state() == GHSwitch.SWITCH_OFF
 
     def get_status(self):
-        if self.get_state() == GHSwitches.SWITCH_ON:
+        """Gets status of switch.
+
+        :returns: Switch status as string.
+        """
+        if self.get_state() == GHSwitch.SWITCH_ON:
             return "ON"
         else:
             return "OFF"
\ No newline at end of file
